@@ -63,7 +63,7 @@ type QuestionRepo interface {
 	GetQuestionsByTitle(ctx context.Context, title string, pageSize int) (questionList []*entity.Question, err error)
 	UpdatePvCount(ctx context.Context, questionID string) (err error)
 	UpdateAnswerCount(ctx context.Context, questionID string, num int) (err error)
-	UpdateCollectionCount(ctx context.Context, questionID string, num int) (err error)
+	UpdateCollectionCount(ctx context.Context, questionID string) (count int64, err error)
 	UpdateAccepted(ctx context.Context, question *entity.Question) (err error)
 	UpdateLastAnswer(ctx context.Context, question *entity.Question) (err error)
 	FindByID(ctx context.Context, id []string) (questionList []*entity.Question, err error)
@@ -135,8 +135,8 @@ func (qs *QuestionCommon) UpdateAnswerCount(ctx context.Context, questionID stri
 	return qs.questionRepo.UpdateAnswerCount(ctx, questionID, int(count))
 }
 
-func (qs *QuestionCommon) UpdateCollectionCount(ctx context.Context, questionID string, num int) error {
-	return qs.questionRepo.UpdateCollectionCount(ctx, questionID, num)
+func (qs *QuestionCommon) UpdateCollectionCount(ctx context.Context, questionID string) (count int64, err error) {
+	return qs.questionRepo.UpdateCollectionCount(ctx, questionID)
 }
 
 func (qs *QuestionCommon) UpdateAccepted(ctx context.Context, questionID, AnswerID string) error {
@@ -297,11 +297,14 @@ func (qs *QuestionCommon) Info(ctx context.Context, questionID string, loginUser
 	isFollowed, _ := qs.followCommon.IsFollowed(ctx, loginUserID, questionID)
 	showinfo.IsFollowed = isFollowed
 
-	has, err = qs.AnswerCommon.SearchAnswered(ctx, loginUserID, dbinfo.ID)
+	ids, err := qs.AnswerCommon.SearchAnswerIDs(ctx, loginUserID, dbinfo.ID)
 	if err != nil {
-		log.Error("AnswerFunc.SearchAnswered", err)
+		log.Error("AnswerFunc.SearchAnswerIDs", err)
+	}
+	showinfo.Answered = len(ids) > 0
+	if showinfo.Answered {
+		showinfo.FirstAnswerId = ids[0]
 	}
-	showinfo.Answered = has
 
 	collectedMap, err := qs.collectionCommon.SearchObjectCollected(ctx, loginUserID, []string{dbinfo.ID})
 	if err != nil {
@@ -593,6 +596,9 @@ func (qs *QuestionCommon) ShowListFormat(ctx context.Context, data *entity.Quest
 func (qs *QuestionCommon) ShowFormat(ctx context.Context, data *entity.Question) *schema.QuestionInfo {
 	info := schema.QuestionInfo{}
 	info.ID = data.ID
+	if handler.GetEnableShortID(ctx) {
+		info.ID = uid.EnShortID(data.ID)
+	}
 	info.Title = data.Title
 	info.UrlTitle = htmltext.UrlTitle(data.Title)
 	info.Content = data.OriginalText
