@@ -17,14 +17,14 @@
  * under the License.
  */
 
-import React, { useState, useEffect, useRef } from 'react';
+import React, { useState, useEffect, useRef, useCallback } from 'react';
 import { Row, Col, Form, Button, Card } from 'react-bootstrap';
 import { useParams, useNavigate, useSearchParams } from 'react-router-dom';
 import { useTranslation } from 'react-i18next';
 
 import dayjs from 'dayjs';
 import classNames from 'classnames';
-import { isEqual } from 'lodash';
+import { isEqual, debounce } from 'lodash';
 
 import { usePageTags, usePromptWithUnload, useCaptchaModal } from '@/hooks';
 import { Editor, EditorRef, TagSelector } from '@/components';
@@ -35,7 +35,7 @@ import {
   questionDetail,
   modifyQuestion,
   useQueryRevisions,
-  useQueryQuestionByTitle,
+  queryQuestionByTitle,
   getTagsBySlugName,
   saveQuestionWithAnswer,
 } from '@/services';
@@ -94,6 +94,7 @@ const Ask = () => {
     setCheckState(false);
     setForceType('');
   };
+  const [similarQuestions, setSimilarQuestions] = useState([]);
 
   const editorRef = useRef<EditorRef>({
     getHtml: () => '',
@@ -117,9 +118,6 @@ const Ask = () => {
   };
 
   const isEdit = qid !== undefined;
-  const { data: similarQuestions = { list: [] } } = useQueryQuestionByTitle(
-    isEdit ? '' : formData.title.value,
-  );
 
   const saveCaptcha = useCaptchaModal('question');
   const editCaptcha = useCaptchaModal('edit');
@@ -221,11 +219,26 @@ const Ask = () => {
     });
   }, [qid]);
 
+  const querySimilarQuestions = useCallback(
+    debounce((title) => {
+      queryQuestionByTitle(title).then((res) => {
+        setSimilarQuestions(res);
+      });
+    }, 400),
+    [],
+  );
+
   const handleTitleChange = (e: React.ChangeEvent<HTMLInputElement>) => {
     setFormData({
       ...formData,
       title: { ...formData.title, value: e.currentTarget.value, errorMsg: '' },
     });
+    if (e.currentTarget.value.length >= 10) {
+      querySimilarQuestions(e.currentTarget.value);
+    }
+    if (e.currentTarget.value.length === 0) {
+      setSimilarQuestions([]);
+    }
   };
   const handleContentChange = (value: string) => {
     setFormData({
@@ -288,7 +301,7 @@ const Ask = () => {
         modifyQuestion(ep)
           .then(async (res) => {
             await editCaptcha.close();
-            navigate(pathFactory.questionLanding(qid, params.url_title), {
+            navigate(pathFactory.questionLanding(qid, res?.url_title), {
               state: { isReview: res?.wait_for_review },
             });
           })
@@ -340,7 +353,7 @@ const Ask = () => {
           if (checked) {
             navigate(pathFactory.questionLanding(id, res?.question?.url_title));
           } else {
-            navigate(pathFactory.questionLanding(id));
+            navigate(pathFactory.questionLanding(id, res?.url_title));
           }
         }
         removeDraft();
